{ config, pkgs, ... }:

{
  imports = [
    ./bemenu.nix
    ./fusuma.nix
    ./init.nix
    ./kanshi.nix
    ./kile
    ./mako.nix
    ./swaybg.nix
    ./swaylock.nix
    ./waybar.nix
    ./zathura.nix
  ];

  home.packages = with pkgs; [
    glib
    gsettings-desktop-schemas
    imv
    light
    pamixer
    playerctl
    ristate
    river
    swaybg
    wl-clipboard
    wtype
    xdg-utils
    (pkgs.callPackage ./screenshot.nix { inherit config pkgs; })
  ];

  programs. zsh. loginExtra = ''
    if [[ -z "''${DISPLAY}" ]] && [[ "''${XDG_VTNR}" -eq 1 ]]; then
        exec ${ pkgs. river}/bin/river
    fi
  '';

  home. sessionVariables. XKB_DEFAULT_LAYOUT = "us";
  home. sessionVariables. XKB_DEFAULT_VARIANT = "altgr-intl";
  home. sessionVariables. XKB_DEFAULT_OPTIONS = "caps:escape";

  systemd. user. targets. river-session = {
    Unit = {
      Description = "river window manager session";
      BindsTo = "graphical-session.target";
      Wants = "graphical-session-pre.target";
      After = "graphical-session-pre.target";
    };
  };

  systemd. user. services. network-manager-applet = {
    Unit = {
      Description = "nm-applet";
      BindsTo = [ "river-session.target" ];
    };
    Service = {
      Type = "simple";
      ExecStart = "${ pkgs. networkmanagerapplet}/bin/nm-applet --indicator";
    };
    Install = { WantedBy = [ "river-session.target" ]; };
  };

  home.sessionVariables = {
    XDG_CURRENT_DESKTOP = "river";
    MOZ_ENABLE_WAYLAND = 1;
  };

}
